@@ -19,9 +19,9 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
     workerFcn=function(.self, df_pg, int_cols, MAP_pg_groups)
     {
       ## completeness check
-      stopifnot(c(int_cols, "contaminant") %in% colnames(df_pg))
+      if (!checkInput(c(int_cols, "contaminant"),df_pg)) return()
       
-      df.con_stats = adply(int_cols, .margins=1, function(group) {
+      df.con_stats = plyr::adply(int_cols, .margins=1, function(group) {
         #cat(group)
         total_int = sum(as.numeric(df_pg[, group]), na.rm = TRUE)
         return(data.frame(group_long = as.character(group),
@@ -68,7 +68,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
     workerFcn=function(.self, df_pg, int_cols, MAP_pg_groups, thresh_intensity)
     {
       ## completeness check
-      stopifnot(c(int_cols, "contaminant") %in% colnames(df_pg))
+      if (!checkInput(c(int_cols, "contaminant"),df_pg)) return()
       
       
       ## some stats (for plot title)
@@ -78,7 +78,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
       medians = sort(apply(log2(df_pg[, int_cols, drop = FALSE]+1), 2, quantile, na.rm = TRUE, probs=0.5)) # + c(0,0,0,0,0,0))
       int_dev = RSD(medians)
       int_dev.s = pastet("INT RSD [%]", round(int_dev, 3))
-      lpl = boxplotCompare(data = melt(df_pg[, c(int_cols, "contaminant"), drop = FALSE], id.vars=c("contaminant"))[,c(2,3,1)],
+      lpl = boxplotCompare(data = reshape2::melt(df_pg[, c(int_cols, "contaminant"), drop = FALSE], id.vars=c("contaminant"))[,c(2,3,1)],
                            log2 = TRUE, 
                            mainlab = "PG: intensity distribution",
                            ylab = expression(log[2]*" intensity"),
@@ -90,7 +90,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
       return(list(plots = lpl))
     }, 
     qcCat = "prep", 
-    qcName = "PG:~raw~intensity", 
+    qcName = "PG:~Raw~intensity", 
     orderNr = 0032
   )
     return(.self)
@@ -119,7 +119,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
     workerFcn=function(.self, df_pg, int_cols, MAP_pg_groups, thresh_intensity)
     {
       ## completeness check
-      stopifnot(c(int_cols, "contaminant") %in% colnames(df_pg))
+      if (!checkInput(c(int_cols, "contaminant"),df_pg)) return()
       
       
       ## some stats (for plot title)
@@ -128,7 +128,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
       ## do not remove zeros (but add +1 since RSD is 'NA' when 'inf' is included in log-data)
       medians = sort(apply(log2(df_pg[, int_cols, drop = FALSE]+1), 2, quantile, na.rm = TRUE, probs=0.5)) # + c(0,0,0,0,0,0))
       int_dev = RSD(medians)
-      lpl = boxplotCompare(data = melt(df_pg[, c(int_cols, "contaminant"), drop = FALSE], id.vars=c("contaminant"))[,c(2,3,1)],
+      lpl = boxplotCompare(data = reshape2::melt(df_pg[, c(int_cols, "contaminant"), drop = FALSE], id.vars=c("contaminant"))[,c(2,3,1)],
                            log2 = TRUE, 
                            mainlab = "PG: LFQ intensity distribution",
                            ylab = expression(log[2]*" intensity"),
@@ -170,7 +170,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
     workerFcn=function(.self, df_pg, int_cols, MAP_pg_groups, thresh_intensity)
     {
       ## completeness check
-      stopifnot(c(int_cols, "contaminant") %in% colnames(df_pg))
+      if (!checkInput(c(int_cols, "contaminant"),df_pg)) return()
       
       
       ## some stats (for plot title)
@@ -179,7 +179,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
       ## do not remove zeros (but add +1 since RSD is 'NA' when 'inf' is included in log-data)
       medians = sort(apply(log2(df_pg[, int_cols, drop = FALSE]+1), 2, quantile, probs=0.5, na.rm = TRUE)) # + c(0,0,0,0,0,0))
       reprt_dev = RSD(medians)
-      lpl = boxplotCompare(   data = melt(df_pg[, c(int_cols, "contaminant"), drop = FALSE], id.vars=c("contaminant"))[,c(2,3,1)],
+      lpl = boxplotCompare(   data = reshape2::melt(df_pg[, c(int_cols, "contaminant"), drop = FALSE], id.vars=c("contaminant"))[,c(2,3,1)],
                               log2 = TRUE, 
                               ylab = expression(log[2]*" reporter intensity"),
                               mainlab = "PG: reporter intensity distribution",
@@ -219,7 +219,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
     workerFcn=function(.self, df_pg, lst_cols, MAP_pg_groups)
     {
       ## completeness check
-      stopifnot(c(unlist(lst_cols), "contaminant") %in% colnames(df_pg))
+      if (!checkInput(c(unlist(lst_cols), "contaminant"),df_pg)) return()
       
       lpl = list()
       for (cond in names(lst_cols))
@@ -268,11 +268,10 @@ automatically assumes a pulsed experiment and reports the label incorporation in
 
 Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to Raw files)
 ",
-    workerFcn=function(.self, df_pg, ratio_cols, thresh_LabelIncorp, GL_name_min_length)
+    workerFcn = function(.self, df_pg, ratio_cols, thresh_LabelIncorp, GL_name_min_length)
     {
       ## completeness check
-      stopifnot(c(ratio_cols, "contaminant", "reverse") %in% colnames(df_pg))
-      
+      if (!checkInput(c(ratio_cols, "contaminant", "reverse"),df_pg)) return()
       
       ## remove reverse and contaminants (might skew the picture)
       idx_row = !df_pg$contaminant & !df_pg$reverse
@@ -322,7 +321,7 @@ Heatmap score: none (since data source proteinGroups.txt is not related 1:1 to R
       
       
       ## compute label incorporation?
-      ratio.mode = ddply(ratio.densities, "col", .fun = function(x) {
+      ratio.mode = plyr::ddply(ratio.densities, "col", .fun = function(x) {
         mode = x$x[which.max(x$y)]
         return (data.frame(mode = mode))
       })
